@@ -1529,6 +1529,7 @@ type Container struct {
 // PodSecurityContext describes the security config for the Pod
 type PodSecurityContext struct {
 	RunAsUser    *int64 `hcl:"run_as_user"`
+	RunAsGroup   *int64 `hcl:"run_as_group"`
 	RunAsNonRoot *bool  `hcl:"run_as_non_root"`
 	FsGroup      *int64 `hcl:"fs_group"`
 }
@@ -1557,6 +1558,8 @@ func (p *Platform) Documentation() (*docs.Documentation, error) {
 	}
 
 	doc.Description("Deploy the application into a Kubernetes cluster using Deployment objects")
+	doc.Input("docker.Image")
+	doc.Output("k8s.Deployment")
 
 	doc.Example(`
 use "kubernetes" {
