@@ -554,25 +554,25 @@ Deploy to a Nomad cluster from a pre-existing Nomad job specification file.
 
 This plugin lets you use any pre-existing Nomad job specification file to
 deploy to Nomad. This deployment is able to support all the features of Waypoint.
-You may use Waypoint's [templating features](/docs/waypoint-hcl/functions/template)
+You may use Waypoint's [templating features](/waypoint/docs/waypoint-hcl/functions/template)
 to template the Nomad jobspec with information such as the artifact from
 a previous build step, entrypoint environment variables, etc.
 
 ### Artifact Access
 
-You may use Waypoint's [templating features](/docs/waypoint-hcl/functions/template)
+You may use Waypoint's [templating features](/waypoint/docs/waypoint-hcl/functions/template)
 to access information such as the artifact from the build or push stages.
 An example below shows this by using ` + "`templatefile`" + ` mixed with
 variables such as ` + "`artifact.image`" + ` to dynamically configure the
 Docker image within the Nomad job specification.
 
--> **Note:** If using [Nomad interpolation](https://www.nomadproject.io/docs/runtime/interpolation) in your jobspec file,
+-> **Note:** If using [Nomad interpolation](/nomad/docs/runtime/interpolation) in your jobspec file,
 and the ` + "`templatefile`" + ` function in your waypoint.hcl file, any interpolated values must be escaped with a second 
 ` + "`$`" + `. For example: ` + "`$${meta.metadata}`" + ` instead of ` + "`${meta.metadata}`" + `.
 
 ### Entrypoint Functionality
 
-Waypoint [entrypoint functionality](/docs/entrypoint#functionality) such
+Waypoint [entrypoint functionality](/waypoint/docs/entrypoint#functionality) such
 as logs, exec, app configuration, and more require two properties to be true:
 
 1. The running image must already have the Waypoint entrypoint installed
@@ -583,17 +583,17 @@ as logs, exec, app configuration, and more require two properties to be true:
   deployment stage.**
 
 **Step 2 does not happen automatically.** You must manually set the entrypoint
-environment variables using the [templating feature](/docs/waypoint-hcl/functions/template).
+environment variables using the [templating feature](/waypoint/docs/waypoint-hcl/functions/template).
 One of the examples below shows the entrypoint environment variables being
 injected.
 
--> **Note:** The Waypoint entrypoint and the [Nomad entrypoint functionality](https://www.nomadproject.io/docs/drivers/docker#entrypoint) 
+-> **Note:** The Waypoint entrypoint and the [Nomad entrypoint functionality](/nomad/docs/drivers/docker#entrypoint) 
 cannot be used simultaneously. In order to use the features of the Waypoint entrypoint, the Nomad entrypoint must not be used in your jobspec.
 
 ### URL Service
 
 If you want your workload to be accessible by the
-[Waypoint URL service](/docs/url), you must set the PORT environment variable
+[Waypoint URL service](/waypoint/docs/url), you must set the PORT environment variable
 within your job and be using the Waypoint entrypoint (documented in the
 previous section).
 
@@ -603,6 +603,9 @@ below for more details.
 
 `)
 
+	doc.Input("docker.Image")
+	doc.Output("jobspec.Deployment")
+
 	doc.Example(`
 deploy {
   use "nomad-jobspec" {
