@@ -617,6 +617,28 @@ func Commands(
 			}, nil
 		},
 
+		"pipeline": func() (cli.Command, error) {
+			return &helpCommand{
+				SynopsisText: helpText["pipeline"][0],
+				HelpText:     helpText["pipeline"][1],
+			}, nil
+		},
+		"pipeline list": func() (cli.Command, error) {
+			return &PipelineListCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+		"pipeline inspect": func() (cli.Command, error) {
+			return &PipelineInspectCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+		"pipeline run": func() (cli.Command, error) {
+			return &PipelineRunCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
+
 		"project": func() (cli.Command, error) {
 			return &helpCommand{
 				SynopsisText: helpText["project"][0],
@@ -638,6 +660,11 @@ func Commands(
 				baseCommand: baseCommand,
 			}, nil
 		},
+		"project destroy": func() (cli.Command, error) {
+			return &ProjectDestroyCommand{
+				baseCommand: baseCommand,
+			}, nil
+		},
 
 		"fmt": func() (cli.Command, error) {
 			return &FmtCommand{
@@ -1049,6 +1076,16 @@ Manage and check the status of jobs in Waypoint.
 `,
 	},
 
+	"pipeline": {
+		"Pipeline management",
+		`
+Pipeline config management.
+
+Pipelines are custom defined Waypoint operations that allow you to customize
+your application delivery experience.
+`,
+	},
+
 	"project": {
 		"Project management",
 		`
