@@ -2,6 +2,8 @@ package cli
 
 import (
 	"context"
+	"fmt"
+	"net/url"
 	"strings"
 
 	"google.golang.org/grpc/codes"
@@ -78,6 +80,22 @@ func (c *UpCommand) Run(args []string) int {
 			result.Deploy.Deployment.Generation.Id != "" &&
 			result.Deploy.Deployment.Generation.InitialSequence != result.Deploy.Deployment.Sequence
 
+		// Ensure deploy and release Urls have a scheme
+		du, err := url.Parse(deployUrl)
+		if err != nil && du.Scheme != "" {
+			return err
+		}
+		if du.Scheme == "" && deployUrl != "" {
+			deployUrl = fmt.Sprintf("https://%s", deployUrl)
+		}
+		ru, err := url.Parse(releaseUrl)
+		if err != nil && ru.Scheme != "" {
+			return err
+		}
+		if ru.Scheme == "" && releaseUrl != "" {
+			releaseUrl = fmt.Sprintf("https://%s", releaseUrl)
+		}
+
 		// Output
 		app.UI.Output("")
 		switch {
