@@ -27,7 +27,7 @@ func (r *Runner) executeConfigSyncOp(
 		panic("operation not expected type")
 	}
 
-	// Do the release
+	// Do the config sync
 	if err := app.ConfigSync(ctx); err != nil {
 		return nil, err
 	}
@@ -35,5 +35,18 @@ func (r *Runner) executeConfigSyncOp(
 		ConfigSync: &pb.Job_ConfigSyncResult{},
 	}
 
+	pipelineResult := make(map[string]*pb.Ref_Pipeline)
+	for _, pipeline := range project.Pipelines() {
+		if err := pipeline.ConfigSync(ctx); err != nil {
+			return nil, err
+		}
+
+		pipelineResult[pipeline.Name()] = pipeline.Ref()
+	}
+
+	result.PipelineConfigSync = &pb.Job_PipelineConfigSyncResult{
+		SyncedPipelines: pipelineResult,
+	}
+
 	return result, nil
 }
