@@ -1,16 +1,18 @@
 package boltdbstate
 
 import (
-	"encoding/binary"
+	"context"
+	"fmt"
+	"regexp"
 	"sort"
 	"strings"
+	"unicode/utf8"
 
+	"github.com/hashicorp/go-memdb"
 	"github.com/mitchellh/hashstructure/v2"
 	bolt "go.etcd.io/bbolt"
 	"google.golang.org/protobuf/proto"
 
-	"github.com/hashicorp/go-memdb"
-
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
 	serversort "github.com/hashicorp/waypoint/pkg/server/sort"
 )
@@ -24,7 +26,7 @@ func init() {
 }
 
 // ConfigSourceSet writes a set of config source values to the database.
-func (s *State) ConfigSourceSet(vs ...*pb.ConfigSource) error {
+func (s *State) ConfigSourceSet(ctx context.Context, vs ...*pb.ConfigSource) error {
 	memTxn := s.inmem.Txn(true)
 	defer memTxn.Abort()
 
@@ -45,14 +47,14 @@ func (s *State) ConfigSourceSet(vs ...*pb.ConfigSource) error {
 }
 
 // ConfigSourceGet gets all the configuration sources for the given request.
-func (s *State) ConfigSourceGet(req *pb.GetConfigSourceRequest) ([]*pb.ConfigSource, error) {
-	return s.ConfigSourceGetWatch(req, nil)
+func (s *State) ConfigSourceGet(ctx context.Context, req *pb.GetConfigSourceRequest) ([]*pb.ConfigSource, error) {
+	return s.ConfigSourceGetWatch(ctx, req, nil)
 }
 
 // ConfigSourceGetWatch gets all the configuration sources for the given request.
 // If a non-nil WatchSet is given, this can be watched for potential changes
 // in the config source settings.
-func (s *State) ConfigSourceGetWatch(req *pb.GetConfigSourceRequest, ws memdb.WatchSet) ([]*pb.ConfigSource, error) {
+func (s *State) ConfigSourceGetWatch(ctx context.Context, req *pb.GetConfigSourceRequest, ws memdb.WatchSet) ([]*pb.ConfigSource, error) {
 	memTxn := s.inmem.Txn(false)
 	defer memTxn.Abort()
 
@@ -299,23 +301,45 @@ func (s *State) configSourceIndexSet(txn *memdb.Txn, id []byte, value *pb.Config
 // configSourceIndexInit initializes the config index from persisted data.
 func (s *State) configSourceIndexInit(dbTxn *bolt.Tx, memTxn *memdb.Txn) error {
 	bucket := dbTxn.Bucket(configSourceBucket)
+
+	// Regex to match for the names of any config sourcer plugins v0.10.5 and earlier
+	re := regexp.MustCompile(`aws-ssm|consul|kubernetes|null|packer|terraform-cloud|vault`)
+
 	return bucket.ForEach(func(k, v []byte) error {
 		var value pb.ConfigSource
 		if err := proto.Unmarshal(v, &value); err != nil {
 			return err
 		}
-		if err := s.configSourceIndexSet(memTxn, k, &value); err != nil {
-			return err
-		}
 
+		// If there are any records whose ID is the name of a plugin, pre-v0.10.4
+		// behavior, then we delete that record from the database, since it is
+		// about to be saved with a hashed ID. This is not very elegant, but
+		// is the simplest way for users to upgrade since custom config sourcer
+		// plugins aren't yet supported, as of 1/10/2023.
+		key := string(k)
+		if re.MatchString(key) || !utf8.Valid(k) {
+			if err := bucket.Delete(k); err != nil {
+				return err
+			}
+			// configSourceSet will create a new record in Bolt DB, AND update
+			// Mem DB, with the ID value hashed as per the v0.10.4 hashing logic.
+			if err := s.configSourceSet(dbTxn, memTxn, &value); err != nil {
+				return err
+			}
+		} else {
+			if err := s.configSourceIndexSet(memTxn, k, &value); err != nil {
+				return err
+			}
+		}
 		return nil
 	})
 }
 
 func (s *State) configSourceId(idHash uint64) []byte {
-	configSourceId := make([]byte, 8)
-	binary.LittleEndian.PutUint64(configSourceId, idHash)
-	return configSourceId
+	// Convert uint64 to string before conversion to byte slice. BoltDB
+	// operations are OK with uint64, but server snapshots (a client of BoltDB)
+	// expect that all keys and values are UTF-8 encoded, which uint64 is not.
+	return []byte(fmt.Sprintf("%d", idHash))
 }
 
 func configSourceIndexSchema() *memdb.TableSchema {
