@@ -19,6 +19,7 @@ import (
 	"google.golang.org/grpc/status"
 
 	"github.com/hashicorp/nomad/api"
+
 	"github.com/hashicorp/waypoint-plugin-sdk/terminal"
 
 	"github.com/hashicorp/waypoint/internal/clicontext"
@@ -68,6 +69,7 @@ type nomadConfig struct {
 	csiVolumeCapacityMin int64             `hcl:"csi_volume_capacity_min,optional"`
 	csiVolumeCapacityMax int64             `hcl:"csi_volume_capacity_max,optional"`
 	csiFS                string            `hcl:"csi_fs,optional"`
+	csiMountFlags        []string          `hcl:"csi_mount_flags,optional"`
 	csiPluginId          string            `hcl:"csi_plugin_id,optional"`
 	csiExternalId        string            `hcl:"nomad_csi_external_id,optional"`
 	csiTopologies        map[string]string `hcl:"nomad_csi_topologies,optional"`
@@ -227,6 +229,7 @@ func (i *NomadInstaller) Install(
 			i.config.csiTopologies,
 			i.config.csiSecrets,
 			i.config.csiParams,
+			i.config.csiMountFlags,
 		)
 		if err != nil {
 			return nil, "", status.Errorf(codes.Internal, "Failed creating Nomad persistent volume: %s", err)
@@ -298,11 +301,11 @@ func (i *NomadInstaller) getWaypointAddress(client *api.Client, allocID string)
 
 		if i.config.consulServiceHostname == "" {
 			return fmt.Sprintf("%s.service.%s.%s:%d",
-					waypointBackendServiceName, i.config.consulDatacenter, i.config.consulDomain, grpcPort), fmt.Sprintf("%s.service.%s.%s:%d",
-					waypointUIServiceName, i.config.consulDatacenter, i.config.consulDomain, httpPort), nil
+					waypointUIServiceName, i.config.consulDatacenter, i.config.consulDomain, httpPort), fmt.Sprintf("%s.service.%s.%s:%d",
+					waypointBackendServiceName, i.config.consulDatacenter, i.config.consulDomain, grpcPort), nil
 		} else {
-			return fmt.Sprintf("%s:%d", i.config.consulServiceHostname, grpcPort),
-				fmt.Sprintf("%s:%d", i.config.consulServiceHostname, httpPort), nil
+			return fmt.Sprintf("%s:%d", i.config.consulServiceHostname, httpPort),
+				fmt.Sprintf("%s:%d", i.config.consulServiceHostname, grpcPort), nil
 		}
 	} else if i.config.serviceProvider == "nomad" {
 		backendService, _, err := client.Services().Get(waypointBackendServiceName, nil)
@@ -640,6 +643,7 @@ func (i *NomadInstaller) InstallRunner(
 			CsiVolumeCapacityMin:  i.config.runnerCsiVolumeCapacityMin,
 			CsiVolumeCapacityMax:  i.config.runnerCsiVolumeCapacityMax,
 			CsiFS:                 i.config.csiFS,
+			CsiMountFlags:         i.config.csiMountFlags,
 			CsiTopologies:         i.config.csiTopologies,
 			CsiExternalId:         i.config.csiExternalId,
 			CsiParams:             i.config.csiParams,
@@ -1338,6 +1342,13 @@ func (i *NomadInstaller) InstallFlags(set *flag.Set) {
 		Default: defaultCSIVolumeMountFS,
 	})
 
+	set.StringSliceVar(&flag.StringSliceVar{
+		Name:    "nomad-csi-mount-flags",
+		Target:  &i.config.csiMountFlags,
+		Usage:   "Nomad CSI volume mount option flags.",
+		Default: []string{"noatime"},
+	})
+
 	set.StringMapVar(&flag.StringMapVar{
 		Name:   "nomad-csi-secrets",
 		Target: &i.config.csiSecrets,
