@@ -93,6 +93,24 @@ func ValidateGetProjectRequest(v *pb.GetProjectRequest) error {
 	))
 }
 
+// ValidateListProjectsRequest
+func ValidateListProjectsRequest(v *pb.ListProjectsRequest) error {
+	return validationext.Error(validation.ValidateStruct(v,
+		validationext.StructField(&v.Pagination, func() []*validation.FieldRules {
+			return ValidatePaginationRequestRules(v.Pagination)
+		}),
+	))
+}
+
+// ValidateUIListProjectsRequest
+func ValidateUIListProjectsRequest(v *pb.UI_ListProjectsRequest) error {
+	return validationext.Error(validation.ValidateStruct(v,
+		validationext.StructField(&v.Pagination, func() []*validation.FieldRules {
+			return ValidatePaginationRequestRules(v.Pagination)
+		}),
+	))
+}
+
 // ValidateDestroyProjectRequest
 func ValidateDestroyProjectRequest(v *pb.DestroyProjectRequest) error {
 	return validationext.Error(validation.ValidateStruct(v,
