@@ -68,16 +68,16 @@ var (
 type userKey struct{}
 
 // UserWithContext inserts the user value u into the context. This can
-// be extracted with userFromContext.
+// be extracted with UserFromContext.
 func UserWithContext(ctx context.Context, u *pb.User) context.Context {
 	return context.WithValue(ctx, userKey{}, u)
 }
 
-// userFromContext returns the authenticated user in the request context.
+// UserFromContext returns the authenticated user in the request context.
 // This will return nil if the user is not authenticated. Note that a user
 // may not be authenticated but the request can still be authenticated
 // using a non-user token type. The safeste way to check is decodedTokenFromContext.
-func (s *Service) userFromContext(ctx context.Context) *pb.User {
+func (s *Service) UserFromContext(ctx context.Context) *pb.User {
 	value, ok := ctx.Value(userKey{}).(*pb.User)
 	if !ok && s.superuser {
 		value = &pb.User{Id: DefaultUserId, Username: DefaultUser}
@@ -139,7 +139,7 @@ func (s *Service) Authenticate(
 
 	// Check the cookie
 	if c := CookieFromRequest(ctx); c != "" {
-		serverConfig, err := s.state(ctx).ServerConfigGet()
+		serverConfig, err := s.state(ctx).ServerConfigGet(ctx)
 		if err != nil {
 			return nil, err
 		}
@@ -220,7 +220,7 @@ func (s *Service) authRunner(
 	}
 
 	// Get our runner
-	r, err := s.state(ctx).RunnerById(runnerId, nil)
+	r, err := s.state(ctx).RunnerById(ctx, runnerId, nil)
 	if status.Code(err) == codes.NotFound {
 		err = nil
 		r = nil
@@ -288,7 +288,7 @@ func (s *Service) authLogin(
 	}
 
 	// Look up the user that this token is for.
-	user, err := s.state(ctx).UserGet(&pb.Ref_User{
+	user, err := s.state(ctx).UserGet(ctx, &pb.Ref_User{
 		Ref: &pb.Ref_User_Id{
 			Id: &pb.Ref_UserId{Id: userId},
 		},
@@ -316,7 +316,7 @@ func (s *Service) authLogin(
 		}
 
 		// Look up the user again
-		user, err = s.state(ctx).UserGet(&pb.Ref_User{
+		user, err = s.state(ctx).UserGet(ctx, &pb.Ref_User{
 			Ref: &pb.Ref_User_Id{
 				Id: &pb.Ref_UserId{Id: userId},
 			},
@@ -342,7 +342,9 @@ func (s *Service) decodeToken(ctx context.Context, token string) (*pb.TokenTrans
 	}
 
 	if subtle.ConstantTimeCompare(data[:len(tokenMagic)], []byte(tokenMagic)) != 1 {
-		return nil, nil, errors.Errorf("bad magic")
+		return nil, nil, errors.Errorf("Failed to decode authentication token. " +
+			"The magic string embedded in the token does not match what was expected. " +
+			"This is likely due to the token string being an invalid auth token.")
 	}
 
 	var tt pb.TokenTransport
@@ -351,7 +353,7 @@ func (s *Service) decodeToken(ctx context.Context, token string) (*pb.TokenTrans
 		return nil, nil, errors.Wrapf(err, "failed to proto unmarshal token")
 	}
 
-	isValid, err := s.state(ctx).TokenSignatureVerify(tt.Body, tt.Signature, tt.KeyId)
+	isValid, err := s.state(ctx).TokenSignatureVerify(ctx, tt.Body, tt.Signature, tt.KeyId)
 	if err != nil {
 		return nil, nil, errors.Wrapf(ErrInvalidToken, err.Error())
 	}
@@ -416,7 +418,7 @@ func (s *Service) encodeToken(ctx context.Context, tt *pb.TokenTransport, body *
 		return "", errors.Wrapf(err, "failed to proto marshal the token")
 	}
 
-	tokenSignature, err := s.state(ctx).TokenSignature(tokenBodyData, tt.KeyId)
+	tokenSignature, err := s.state(ctx).TokenSignature(ctx, tokenBodyData, tt.KeyId)
 	if err != nil {
 		return "", errors.Wrapf(err, "failed getting token signature")
 	}
@@ -446,7 +448,7 @@ func (s *Service) GenerateLoginToken(
 	log := hclog.FromContext(ctx)
 
 	// Get our user, that's what we log in as
-	currentUser := s.userFromContext(ctx)
+	currentUser := s.UserFromContext(ctx)
 
 	// If we have a duration set, set the expiry
 	var dur time.Duration
@@ -471,7 +473,7 @@ func (s *Service) GenerateLoginToken(
 
 	// If we're authing as another user, we have to get that user
 	if req.User != nil {
-		user, err := s.state(ctx).UserGet(req.User)
+		user, err := s.state(ctx).UserGet(ctx, req.User)
 		if err != nil {
 			return nil, err
 		}
@@ -606,7 +608,7 @@ func (s *Service) GenerateInviteToken(
 ) (*pb.NewTokenResponse, error) {
 	log := hclog.FromContext(ctx)
 
-	currentUser := s.userFromContext(ctx)
+	currentUser := s.UserFromContext(ctx)
 	if currentUser == nil {
 		return nil, status.Errorf(codes.Unauthenticated, "current user is not authenticated")
 	}
@@ -636,7 +638,7 @@ func (s *Service) GenerateInviteToken(
 	// req.Login.UserId is authored by the caller and won't be an encoded id
 	// so we don't decode it, but we will be sure the resulting token is encoded.
 	if req.Login.UserId != currentUser.Id && req.Signup == nil {
-		_, err := s.state(ctx).UserGet(&pb.Ref_User{
+		_, err := s.state(ctx).UserGet(ctx, &pb.Ref_User{
 			Ref: &pb.Ref_User_Id{
 				Id: &pb.Ref_UserId{Id: req.Login.UserId},
 			},
@@ -702,7 +704,7 @@ func (s *Service) ConvertInviteToken(ctx context.Context, req *pb.ConvertInviteT
 	// If we have a signup invite, then create a new user.
 	if signup := invite.Signup; signup != nil {
 		user := &pb.User{Username: signup.InitialUsername}
-		if err := s.state(ctx).UserPut(user); err != nil {
+		if err := s.state(ctx).UserPut(ctx, user); err != nil {
 			return nil, err
 		}
 
@@ -730,7 +732,7 @@ func (s *Service) ConvertInviteToken(ctx context.Context, req *pb.ConvertInviteT
 
 // BootstrapToken RPC call.
 func (s *Service) BootstrapToken(ctx context.Context, req *empty.Empty) (*pb.NewTokenResponse, error) {
-	if !s.state(ctx).HMACKeyEmpty() {
+	if !s.state(ctx).HMACKeyEmpty(ctx) {
 		return nil, status.Errorf(codes.PermissionDenied, "server is already bootstrapped")
 	}
 
@@ -758,7 +760,7 @@ func (s *Service) BootstrapToken(ctx context.Context, req *empty.Empty) (*pb.New
 // bootstrapUser creates the initial default user. This will always attempt
 // to create the user so gating logic to prevent that is up to the caller.
 func (s *Service) bootstrapUser(ctx context.Context) (*pb.User, error) {
-	empty, err := s.state(ctx).UserEmpty()
+	empty, err := s.state(ctx).UserEmpty(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -772,13 +774,13 @@ func (s *Service) bootstrapUser(ctx context.Context) (*pb.User, error) {
 		Username: DefaultUser,
 	}
 
-	return user, s.state(ctx).UserPut(user)
+	return user, s.state(ctx).UserPut(ctx, user)
 }
 
 // Bootstrapped returns true if the server is already bootstrapped. If
 // this returns true then BootstrapToken can no longer be called.
 func (s *Service) Bootstrapped(ctx context.Context) bool {
-	return !s.state(ctx).HMACKeyEmpty()
+	return !s.state(ctx).HMACKeyEmpty(ctx)
 }
 
 // DecodeToken RPC call.
