@@ -3,6 +3,7 @@ package singleprocess
 import (
 	"context"
 	"encoding/json"
+	"errors"
 	"fmt"
 	"time"
 
@@ -15,6 +16,7 @@ import (
 
 	wpoidc "github.com/hashicorp/waypoint/pkg/auth/oidc"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
 )
 
@@ -38,9 +40,13 @@ func (s *Service) ListOIDCAuthMethods(
 	// index OIDC methods specifically and do this more efficiently but
 	// realistically we don't expect there to ever be that many auth methods.
 	// Even if there were thousands (why????) this would be okay.
-	values, err := s.state(ctx).AuthMethodList()
+	values, err := s.state(ctx).AuthMethodList(ctx)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to list OIDC auth methods",
+		)
 	}
 
 	// Go through and extract the auth methods
@@ -70,28 +76,50 @@ func (s *Service) GetOIDCAuthURL(
 	}
 
 	// Get the auth method
-	am, err := s.state(ctx).AuthMethodGet(req.AuthMethod)
+	am, err := s.state(ctx).AuthMethodGet(ctx, req.AuthMethod)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get OIDC auth method",
+			"auth_method",
+			req.AuthMethod.GetName(),
+		)
 	}
 
 	// The auth method must be OIDC
 	amMethod, ok := am.Method.(*pb.AuthMethod_Oidc)
 	if !ok {
-		return nil, status.Errorf(codes.FailedPrecondition,
-			"auth method is not OIDC")
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			status.Errorf(codes.FailedPrecondition,
+				"auth method is not OIDC"),
+			"auth method is not an OIDC auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// We need our server config.
-	sc, err := s.state(ctx).ServerConfigGet()
+	sc, err := s.state(ctx).ServerConfigGet(ctx)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get server config when looking up OIDC auth method",
+		)
 	}
 
 	// Get our OIDC provider
 	provider, err := s.oidcCache.Get(ctx, am, sc)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get OIDC auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Create a minimal request to get the auth URL
@@ -107,13 +135,25 @@ func (s *Service) GetOIDCAuthURL(
 		oidcReqOpts...,
 	)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"OIDC request failed for auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Get the auth URL
 	url, err := provider.AuthURL(ctx, oidcReq)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get auth URL for OIDC auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	return &pb.GetOIDCAuthURLResponse{
@@ -132,28 +172,50 @@ func (s *Service) CompleteOIDCAuth(
 	}
 
 	// Get the auth method
-	am, err := s.state(ctx).AuthMethodGet(req.AuthMethod)
+	am, err := s.state(ctx).AuthMethodGet(ctx, req.AuthMethod)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get OIDC auth method",
+			"auth_method",
+			req.AuthMethod.GetName(),
+		)
 	}
 
 	// The auth method must be OIDC
 	amMethod, ok := am.Method.(*pb.AuthMethod_Oidc)
 	if !ok {
-		return nil, status.Errorf(codes.FailedPrecondition,
-			"auth method is not OIDC")
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			status.Errorf(codes.FailedPrecondition,
+				"auth method is not OIDC"),
+			"auth method is not an OIDC auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// We need our server config.
-	sc, err := s.state(ctx).ServerConfigGet()
+	sc, err := s.state(ctx).ServerConfigGet(ctx)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get server config when looking up OIDC auth method",
+		)
 	}
 
 	// Get our OIDC provider
 	provider, err := s.oidcCache.Get(ctx, am, sc)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get OIDC auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Create a minimal request to get the auth URL
@@ -179,24 +241,48 @@ func (s *Service) CompleteOIDCAuth(
 	// Exchange our code for our token
 	oidcToken, err := provider.Exchange(ctx, oidcReq, req.State, req.Code)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"OIDC request failed to exchange token for auth method",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Extract the claims as a raw JSON message.
 	var jsonClaims json.RawMessage
 	if err := oidcToken.IDToken().Claims(&jsonClaims); err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to retrieve OIDC claims from auth method token",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Structurally extract only the claim fields we care about.
 	var idClaimVals idClaims
 	if err := json.Unmarshal([]byte(jsonClaims), &idClaimVals); err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to extract OIDC claims from auth method token",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// Valid OIDC providers should never behave this way.
 	if idClaimVals.Iss == "" || idClaimVals.Sub == "" {
-		return nil, status.Errorf(codes.Internal, "OIDC provider returned empty issuer or subscriber ID")
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			errors.New("OIDC provider returned empty issuer or subscriber ID"),
+			"OIDC provider returned empty issuer or subscriber ID",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	// From this point forward, log all data
@@ -210,7 +296,13 @@ func (s *Service) CompleteOIDCAuth(
 	var userClaims json.RawMessage
 	if userTokenSource := oidcToken.StaticTokenSource(); userTokenSource != nil {
 		if err := provider.UserInfo(ctx, userTokenSource, idClaimVals.Sub, &userClaims); err != nil {
-			return nil, err
+			return nil, hcerr.Externalize(
+				hclog.FromContext(ctx),
+				err,
+				"failed to extract userinfo from claims",
+				"auth_method",
+				am.Name,
+			)
 		}
 	}
 
@@ -219,18 +311,36 @@ func (s *Service) CompleteOIDCAuth(
 		// Get our data
 		selectorData, err := wpoidc.SelectorData(amMethod.Oidc, jsonClaims, userClaims)
 		if err != nil {
-			return nil, err
+			return nil, hcerr.Externalize(
+				hclog.FromContext(ctx),
+				err,
+				"error processiong OIDC claims",
+				"auth_method",
+				am.Name,
+			)
 		}
 
 		eval, err := bexpr.CreateEvaluator(am.AccessSelector)
 		if err != nil {
 			// This shouldn't happen since we validate on auth method create.
-			return nil, err
+			return nil, hcerr.Externalize(
+				hclog.FromContext(ctx),
+				err,
+				"error creating OIDC evaluator",
+				"auth_method",
+				am.Name,
+			)
 		}
 
 		allowed, err := eval.Evaluate(selectorData)
 		if err != nil {
-			return nil, err
+			return nil, hcerr.Externalize(
+				hclog.FromContext(ctx),
+				err,
+				"error evaluating OIDC selector claims",
+				"auth_method",
+				am.Name,
+			)
 		}
 
 		if !allowed {
@@ -240,16 +350,28 @@ func (s *Service) CompleteOIDCAuth(
 				"selector", am.AccessSelector,
 			)
 
-			return nil, status.Errorf(codes.PermissionDenied,
+			return nil, hcerr.Externalize(
+				hclog.FromContext(ctx),
+				status.Errorf(codes.PermissionDenied, "rejected OIDC login based on access selector"),
 				"Your account was denied access. Please contact your Waypoint "+
-					"server administrator for more information.")
+					"server administrator for more information.",
+				"auth_method",
+				am.Name,
+			)
 		}
 	}
 
 	// Look up a user by sub.
 	user, err := s.oidcInitUser(ctx, log, &idClaimVals)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error finding or creating OIDC user",
+			"auth_method",
+			am.Name,
+			// not sure if we should log out idClaimVals.Email here as well
+		)
 	}
 
 	// Generate a token for this user
@@ -259,7 +381,13 @@ func (s *Service) CompleteOIDCAuth(
 		},
 	})
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error generating new token for OIDC user",
+			"auth_method",
+			am.Name,
+		)
 	}
 
 	return &pb.CompleteOIDCAuthResponse{
@@ -288,7 +416,7 @@ func (s *Service) oidcInitUser(ctx context.Context, log hclog.Logger, claims *id
 	}
 
 	// First look up by exact account link.
-	user, err := s.state(ctx).UserGetOIDC(claims.Iss, claims.Sub)
+	user, err := s.state(ctx).UserGetOIDC(ctx, claims.Iss, claims.Sub)
 	if err != nil {
 		if status.Code(err) != codes.NotFound {
 			return nil, err
@@ -303,7 +431,7 @@ func (s *Service) oidcInitUser(ctx context.Context, log hclog.Logger, claims *id
 
 	// Look up the user by email if we don't have a user by sub.
 	if email != "" {
-		user, err = s.state(ctx).UserGetEmail(email)
+		user, err = s.state(ctx).UserGetEmail(ctx, email)
 		if err != nil {
 			if status.Code(err) != codes.NotFound {
 				return nil, err
@@ -338,7 +466,7 @@ func (s *Service) oidcInitUser(ctx context.Context, log hclog.Logger, claims *id
 		},
 	})
 
-	if err := s.state(ctx).UserPut(user); err != nil {
+	if err := s.state(ctx).UserPut(ctx, user); err != nil {
 		return nil, err
 	}
 
