@@ -3,7 +3,9 @@ package singleprocess
 import (
 	"context"
 
+	"github.com/hashicorp/go-hclog"
 	pb "github.com/hashicorp/waypoint/pkg/server/gen"
+	"github.com/hashicorp/waypoint/pkg/server/hcerr"
 	serverptypes "github.com/hashicorp/waypoint/pkg/server/ptypes"
 )
 
@@ -15,9 +17,13 @@ func (s *Service) ListPipelineRuns(
 		return nil, err
 	}
 
-	result, err := s.state(ctx).PipelineRunList(req.Pipeline)
+	result, err := s.state(ctx).PipelineRunList(ctx, req.Pipeline)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to push pipeline run",
+		)
 	}
 
 	return &pb.ListPipelineRunsResponse{
@@ -33,9 +39,13 @@ func (s *Service) GetPipelineRun(
 		return nil, err
 	}
 
-	result, err := s.state(ctx).PipelineRunGet(req.Pipeline, req.Sequence)
+	result, err := s.state(ctx).PipelineRunGet(ctx, req.Pipeline, req.Sequence)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get pipeline run",
+		)
 	}
 
 	return &pb.GetPipelineRunResponse{
@@ -51,14 +61,22 @@ func (s *Service) GetLatestPipelineRun(
 		return nil, err
 	}
 
-	pipeline, err := s.state(ctx).PipelineGet(req.Pipeline)
+	pipeline, err := s.state(ctx).PipelineGet(ctx, req.Pipeline)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"error getting pipeline",
+		)
 	}
 
-	latestPipelineRun, err := s.state(ctx).PipelineRunGetLatest(pipeline.Id)
+	latestPipelineRun, err := s.state(ctx).PipelineRunGetLatest(ctx, pipeline.Id)
 	if err != nil {
-		return nil, err
+		return nil, hcerr.Externalize(
+			hclog.FromContext(ctx),
+			err,
+			"failed to get latest pipeline run",
+		)
 	}
 
 	return &pb.GetPipelineRunResponse{
