@@ -71,7 +71,7 @@ func TestServiceJob(t *testing.T, factory Factory) {
 		require.Nil(job)
 	})
 
-	_, err := impl.State(context.Background()).JobList(&pb.ListJobsRequest{})
+	_, _, err := impl.State(ctx).JobList(ctx, &pb.ListJobsRequest{})
 	require.NoError(t, err)
 
 }
@@ -166,7 +166,7 @@ func TestServiceJob_List(t *testing.T, factory Factory) {
 		require.Equal(jobList.Jobs[0].Workspace.Workspace, "prod")
 
 		proj := serverptypes.TestProject(t, &pb.Project{Name: "new"})
-		_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+		_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 			Project: proj,
 		})
 		require.NoError(err)
@@ -490,7 +490,7 @@ func TestServiceGetJobStream_complete(t *testing.T, factory Factory) {
 	// getJobStreamOutputInit, from pkg/server/singleprocess; otherwise, the
 	// output will be buffered. If this test becomes flakey, this time should
 	// be increased.
-	time.Sleep(200 * time.Millisecond)
+	time.Sleep(1 * time.Second)
 
 	// Send some output
 	require.NoError(runnerStream.Send(&pb.RunnerJobStreamRequest{
@@ -1017,7 +1017,7 @@ func TestServiceQueueJob_odr_basic(t *testing.T, factory Factory) {
 			"CARPET_DRIVER": "apu",
 		},
 	})
-	cfgResp, err := client.UpsertOnDemandRunnerConfig(context.Background(), &pb.UpsertOnDemandRunnerConfigRequest{
+	cfgResp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
 		Config: odr,
 	})
 	odr = cfgResp.Config
@@ -1025,7 +1025,7 @@ func TestServiceQueueJob_odr_basic(t *testing.T, factory Factory) {
 
 	// Update the project to include ondemand runner
 	proj := serverptypes.TestProject(t, &pb.Project{Name: "proj"})
-	_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+	_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 		Project: proj,
 	})
 	require.NoError(err)
@@ -1381,13 +1381,13 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 	require.NotEmpty(queueResp)
 
 	// Job should exist and be queued
-	job, err := impl.State(context.Background()).JobById(queueResp.JobId, nil)
+	job, err := impl.State(ctx).JobById(ctx, queueResp.JobId, nil)
 	require.NoError(err)
 	require.Equal(pb.Job_QUEUED, job.State)
 	primaryJobId := job.Id
 
 	// task should be PENDING
-	task, err := impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err := impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: queueResp.JobId,
 		},
@@ -1458,7 +1458,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 	// the JobAck. We do this a few times in this test to account for CI machine
 	// slowness.
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1475,7 +1475,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 
 	// task should be STARTED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1511,7 +1511,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 
 		// task should be RUNNING
 		time.Sleep(200 * time.Millisecond)
-		task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+		task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 			Ref: &pb.Ref_Task_JobId{
 				JobId: queueResp.JobId,
 			},
@@ -1529,7 +1529,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 
 	// task should be COMPLETED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1621,7 +1621,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 
 	// task should be STOPPING
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1638,7 +1638,7 @@ func TestServiceQueueJob_odr_customTask(t *testing.T, factory Factory) {
 
 	// task should be STOPPED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1709,12 +1709,12 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 	require.NotEmpty(queueResp)
 
 	// Job should exist and be queued
-	job, err := impl.State(context.Background()).JobById(queueResp.JobId, nil)
+	job, err := impl.State(ctx).JobById(ctx, queueResp.JobId, nil)
 	require.NoError(err)
 	require.Equal(pb.Job_QUEUED, job.State)
 
 	// task should be PENDING
-	task, err := impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err := impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: queueResp.JobId,
 		},
@@ -1777,7 +1777,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 	// the JobAck. We do this a few times in this test to account for CI machine
 	// slowness.
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1794,7 +1794,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 
 	// task should be STARTED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1829,7 +1829,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 
 		// task should be RUNNING
 		time.Sleep(200 * time.Millisecond)
-		task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+		task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 			Ref: &pb.Ref_Task_JobId{
 				JobId: queueResp.JobId,
 			},
@@ -1847,7 +1847,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 
 	// task should be COMPLETED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1891,7 +1891,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 
 	// task should be STOPPING
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1908,7 +1908,7 @@ func TestServiceQueueJob_odr_customTaskSkipOp(t *testing.T, factory Factory) {
 
 	// task should be STOPPED
 	time.Sleep(200 * time.Millisecond)
-	task, err = impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err = impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: job.Id,
 		},
@@ -1952,7 +1952,7 @@ func TestServiceQueueJob_odr_default(t *testing.T, factory Factory) {
 		Default: true,
 	})
 
-	cfgResp, err := client.UpsertOnDemandRunnerConfig(context.Background(), &pb.UpsertOnDemandRunnerConfigRequest{
+	cfgResp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
 		Config: odr,
 	})
 
@@ -1962,7 +1962,7 @@ func TestServiceQueueJob_odr_default(t *testing.T, factory Factory) {
 
 	// Update the project to include ondemand runner
 	proj := serverptypes.TestProject(t, &pb.Project{Name: "proj"})
-	_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+	_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 		Project: proj,
 	})
 
@@ -2118,14 +2118,14 @@ func TestServiceQueueJob_odr_target_id(t *testing.T, factory Factory) {
 			},
 		},
 	})
-	cfgResp, err := client.UpsertOnDemandRunnerConfig(context.Background(), &pb.UpsertOnDemandRunnerConfigRequest{
+	cfgResp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
 		Config: odr,
 	})
 	odr = cfgResp.Config
 	log.Info("test odr profile", "name", odr.Name)
 
 	proj := serverptypes.TestProject(t, &pb.Project{Name: "proj"})
-	_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+	_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 		Project: proj,
 	})
 	require.NoError(err)
@@ -2283,14 +2283,14 @@ func TestServiceQueueJob_odr_target_labels(t *testing.T, factory Factory) {
 			},
 		},
 	})
-	cfgResp, err := client.UpsertOnDemandRunnerConfig(context.Background(), &pb.UpsertOnDemandRunnerConfigRequest{
+	cfgResp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
 		Config: odr,
 	})
 	odr = cfgResp.Config
 	log.Info("test odr profile", "name", odr.Name)
 
 	proj := serverptypes.TestProject(t, &pb.Project{Name: "proj"})
-	_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+	_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 		Project: proj,
 	})
 	require.NoError(err)
@@ -2432,14 +2432,14 @@ func TestServiceQueueJob_odr_depends(t *testing.T, factory Factory) {
 			"CARPET_DRIVER": "apu",
 		},
 	})
-	cfgResp, err := client.UpsertOnDemandRunnerConfig(context.Background(), &pb.UpsertOnDemandRunnerConfigRequest{
+	cfgResp, err := client.UpsertOnDemandRunnerConfig(ctx, &pb.UpsertOnDemandRunnerConfigRequest{
 		Config: odr,
 	})
 	odr = cfgResp.Config
 
 	// Update the project to include ondemand runner
 	proj := serverptypes.TestProject(t, &pb.Project{Name: "proj"})
-	_, err = client.UpsertProject(context.Background(), &pb.UpsertProjectRequest{
+	_, err = client.UpsertProject(ctx, &pb.UpsertProjectRequest{
 		Project: proj,
 	})
 	require.NoError(err)
@@ -2481,7 +2481,7 @@ func TestServiceQueueJob_odr_depends(t *testing.T, factory Factory) {
 	require.NotEmpty(queueResp)
 
 	// Get the task to get the start job
-	task, err := impl.State(context.Background()).TaskGet(&pb.Ref_Task{
+	task, err := impl.State(ctx).TaskGet(ctx, &pb.Ref_Task{
 		Ref: &pb.Ref_Task_JobId{
 			JobId: queueResp.JobId,
 		},
@@ -2490,7 +2490,7 @@ func TestServiceQueueJob_odr_depends(t *testing.T, factory Factory) {
 	require.Equal(pb.Task_PENDING, task.JobState)
 
 	// Get the start job
-	job, err := impl.State(context.Background()).JobById(task.StartJob.Id, nil)
+	job, err := impl.State(ctx).JobById(ctx, task.StartJob.Id, nil)
 	require.NoError(err)
 	require.IsType(&pb.Job_StartTask{}, job.Operation)
 	require.Equal([]string{queueA.JobId, queueB.JobId}, job.DependsOn)
