@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 	"time"
 
@@ -20,7 +21,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 	// field. This is done on purpose because I wanted to retain tests
 	// from our old format to ensure that we have backwards compatibility.
 	// New functionality uses the new format.
-
+	ctx := context.Background()
 	t.Run("basic put and get", func(t *testing.T) {
 		require := require.New(t)
 
@@ -28,7 +29,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -40,7 +41,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}))
 
 		// Create a runner config, we should never get this
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Project{
 					Project: &pb.Ref_Project{
@@ -61,7 +62,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -74,7 +75,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it via a prefix match
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -87,7 +88,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// non-matching prefix
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -106,7 +107,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -130,7 +131,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -145,7 +146,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it via a prefix match
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -158,7 +159,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// non-matching prefix
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -178,6 +179,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Create vars
 		require.NoError(s.ConfigSet(
+			ctx,
 			&pb.ConfigVar{
 				Target: &pb.ConfigVar_Target{
 					AppScope: &pb.ConfigVar_Target_Global{
@@ -223,7 +225,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get our merged variables
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -245,7 +247,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get project scoped variables. This should return everything.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{
 						Project: "foo",
@@ -264,7 +266,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a var
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -277,7 +279,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -289,7 +291,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Delete it
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -302,7 +304,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		// Should not exist
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -321,7 +323,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a var
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -334,7 +336,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -346,7 +348,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Delete it
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -362,7 +364,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		// Should not exist
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -381,7 +383,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a var
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -394,7 +396,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -406,7 +408,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Delete it
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -420,7 +422,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		// Should not exist
 		{
 			// Get it exactly
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Project{
 					Project: &pb.Ref_Project{Project: "foo"},
 				},
@@ -439,7 +441,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create the config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Runner{
 				Runner: &pb.Ref_Runner{
 					Target: &pb.Ref_Runner_Any{
@@ -453,7 +455,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}))
 
 		// Create a var that shouldn't match
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -466,7 +468,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 
 				Prefix: "foo",
@@ -477,7 +479,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it via a prefix match
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 
 				Prefix: "",
@@ -488,7 +490,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// non-matching prefix
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 
 				Prefix: "bar",
@@ -505,7 +507,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create the config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Runner{
 				Runner: &pb.Ref_Runner{
 					Target: &pb.Ref_Runner_Id{
@@ -521,7 +523,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}))
 
 		// Create a var that shouldn't match
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
@@ -534,7 +536,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 
 				Prefix: "foo",
@@ -545,7 +547,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Doesn't match
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_B"},
 
 				Prefix: "foo",
@@ -562,7 +564,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create the config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Runner{
 				Runner: &pb.Ref_Runner{
 					Target: &pb.Ref_Runner_Any{
@@ -575,7 +577,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 			Value: &pb.ConfigVar_Static{Static: "bar"},
 		}))
 
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Runner{
 				Runner: &pb.Ref_Runner{
 					Target: &pb.Ref_Runner_Id{
@@ -592,7 +594,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 
 				Prefix: "foo",
@@ -610,7 +612,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create the config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -630,7 +632,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 			Value: &pb.ConfigVar_Static{Static: "bar"},
 		}))
 
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Global{
 					Global: &pb.Ref_Global{},
@@ -651,7 +653,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it exactly.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -669,7 +671,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Get it for a global runner scope.
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Runner: &pb.Ref_RunnerId{Id: "R_A"},
 			})
 			require.NoError(err)
@@ -685,7 +687,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -703,7 +705,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// No workspace set
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -719,7 +721,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Matching workspace
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -735,7 +737,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Non-Matching workspace
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -757,7 +759,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a config that overrides based on workspace
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -770,7 +772,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 			Name:  "foo",
 			Value: &pb.ConfigVar_Static{Static: "one"},
 		}))
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -788,7 +790,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Matching workspace
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -805,7 +807,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Non-Matching workspace
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -828,7 +830,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a config that overrides based on workspace
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -843,7 +845,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 			Name:  "foo",
 			Value: &pb.ConfigVar_Static{Static: "one"},
 		}))
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -860,7 +862,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}))
 
 		{
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -876,7 +878,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		{
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -899,7 +901,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 		defer s.Close()
 
 		// Create a build
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			Target: &pb.ConfigVar_Target{
 				AppScope: &pb.ConfigVar_Target_Application{
 					Application: &pb.Ref_Application{
@@ -917,7 +919,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// No labels set
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -933,7 +935,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Matching labels
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -949,7 +951,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		{
 			// Non-Matching workspace
-			vs, err := s.ConfigGet(&pb.ConfigGetRequest{
+			vs, err := s.ConfigGet(ctx, &pb.ConfigGetRequest{
 				Scope: &pb.ConfigGetRequest_Application{
 					Application: &pb.Ref_Application{
 						Project:     "foo",
@@ -966,6 +968,7 @@ func TestConfig(t *testing.T, factory Factory, restartF RestartFactory) {
 }
 
 func TestConfigWatch(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
 	t.Run("watches for new variables", func(t *testing.T) {
 		require := require.New(t)
 
@@ -975,7 +978,7 @@ func TestConfigWatch(t *testing.T, factory Factory, restartF RestartFactory) {
 		ws := memdb.NewWatchSet()
 
 		// Get it with watch
-		vs, err := s.ConfigGetWatch(&pb.ConfigGetRequest{
+		vs, err := s.ConfigGetWatch(ctx, &pb.ConfigGetRequest{
 			Scope: &pb.ConfigGetRequest_Project{
 				Project: &pb.Ref_Project{Project: "foo"},
 			},
@@ -989,7 +992,7 @@ func TestConfigWatch(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.True(ws.Watch(time.After(10 * time.Millisecond)))
 
 		// Create a config
-		require.NoError(s.ConfigSet(&pb.ConfigVar{
+		require.NoError(s.ConfigSet(ctx, &pb.ConfigVar{
 			UnusedScope: &pb.ConfigVar_Project{
 				Project: &pb.Ref_Project{
 					Project: "foo",
