@@ -1,6 +1,7 @@
 package statetest
 
 import (
+	"context"
 	"testing"
 	"time"
 
@@ -19,6 +20,7 @@ func init() {
 }
 
 func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
+	ctx := context.Background()
 	t.Run("CRUD operations", func(t *testing.T) {
 		require := require.New(t)
 
@@ -27,13 +29,13 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Write project
 		ref := &pb.Ref_Project{Project: "foo"}
-		require.NoError(s.ProjectPut(serverptypes.TestProject(t, &pb.Project{
+		require.NoError(s.ProjectPut(ctx, serverptypes.TestProject(t, &pb.Project{
 			Name: ref.Project,
 		})))
 
 		// Has no apps
 		{
-			resp, err := s.ProjectGet(ref)
+			resp, err := s.ProjectGet(ctx, ref)
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Empty(resp.Applications)
@@ -49,7 +51,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Add
-		err := s.ReleasePut(false, serverptypes.TestRelease(t, &pb.Release{
+		err := s.ReleasePut(ctx, false, serverptypes.TestRelease(t, &pb.Release{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -62,7 +64,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read
 		{
-			resp, err := s.ReleaseGet(&pb.Ref_Operation{
+			resp, err := s.ReleaseGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -73,14 +75,14 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Can read latest
 		{
-			resp, err := s.ReleaseLatest(app, &pb.Ref_Workspace{Workspace: "default"})
+			resp, err := s.ReleaseLatest(ctx, app, &pb.Ref_Workspace{Workspace: "default"})
 			require.NoError(err)
 			require.NotNil(resp)
 		}
 
 		// Update
 		ts := timestamppb.Now()
-		err = s.ReleasePut(true, serverptypes.TestRelease(t, &pb.Release{
+		err = s.ReleasePut(ctx, true, serverptypes.TestRelease(t, &pb.Release{
 			Id:          "d1",
 			Application: app,
 			Workspace:   ws,
@@ -93,7 +95,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.ReleaseGet(&pb.Ref_Operation{
+			resp, err := s.ReleaseGet(ctx, &pb.Ref_Operation{
 				Target: &pb.Ref_Operation_Id{
 					Id: "d1",
 				},
@@ -105,7 +107,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		// Add another in another workspace, and see Latest change
-		err = s.ReleasePut(false, serverptypes.TestRelease(t, &pb.Release{
+		err = s.ReleasePut(ctx, false, serverptypes.TestRelease(t, &pb.Release{
 			Id:          "d2",
 			Application: app,
 			Workspace:   &pb.Ref_Workspace{Workspace: "non-default"},
@@ -119,7 +121,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Get by workspace
 		{
-			resp, err := s.ReleaseLatest(app, &pb.Ref_Workspace{Workspace: "non-default"})
+			resp, err := s.ReleaseLatest(ctx, app, &pb.Ref_Workspace{Workspace: "non-default"})
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Equal("d2", resp.Id)
@@ -127,7 +129,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 
 		// Get with no workspace
 		{
-			resp, err := s.ReleaseLatest(app, nil)
+			resp, err := s.ReleaseLatest(ctx, app, nil)
 			require.NoError(err)
 			require.NotNil(resp)
 			require.Equal("d2", resp.Id)
@@ -137,7 +139,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		// ReleaseLatest (with no workspace filter) returns the latest one.
 
 		{
-			resp, err := s.ReleaseList(app)
+			resp, err := s.ReleaseList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 2)
@@ -160,7 +162,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		*/
 
 		{
-			resp, err := s.ReleaseList(app, serverstate.ListWithOrder(&pb.OperationOrder{
+			resp, err := s.ReleaseList(ctx, app, serverstate.ListWithOrder(&pb.OperationOrder{
 				Order: pb.OperationOrder_START_TIME,
 				Desc:  true,
 				Limit: 1,
@@ -172,7 +174,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 			require.Equal("d2", resp[0].Id)
 		}
 
-		err = s.ReleasePut(false, serverptypes.TestRelease(t, &pb.Release{
+		err = s.ReleasePut(ctx, false, serverptypes.TestRelease(t, &pb.Release{
 			Id:          "d3",
 			Application: app,
 			Workspace:   ws,
@@ -184,14 +186,14 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		require.NoError(err)
 
 		{
-			resp, err := s.ReleaseList(app)
+			resp, err := s.ReleaseList(ctx, app)
 			require.NoError(err)
 
 			require.Len(resp, 3)
 		}
 
 		{
-			resp, err := s.ReleaseList(app,
+			resp, err := s.ReleaseList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
@@ -214,7 +216,7 @@ func TestRelease(t *testing.T, factory Factory, restartF RestartFactory) {
 		}
 
 		{
-			resp, err := s.ReleaseList(app,
+			resp, err := s.ReleaseList(ctx, app,
 				serverstate.ListWithOrder(&pb.OperationOrder{
 					Order: pb.OperationOrder_START_TIME,
 					Desc:  true,
