@@ -1,12 +1,14 @@
 import Route from '@ember/routing/route';
 import { inject as service } from '@ember/service';
 import ApiService from 'waypoint/services/api';
-import { GetProjectRequest, Project, Ref } from 'waypoint-pb';
+import { UI, Project, Ref, Job } from 'waypoint-pb';
 import PollModelService from 'waypoint/services/poll-model';
 import { Breadcrumb } from 'waypoint/services/breadcrumbs';
 
 export type Params = { project_id: string };
-export type Model = Project.AsObject;
+export type Model = Project.AsObject & {
+  latestInitJob?: Job.AsObject;
+};
 
 export default class ProjectDetail extends Route {
   @service api!: ApiService;
@@ -23,10 +25,10 @@ export default class ProjectDetail extends Route {
     // Setup the project request
     let ref = new Ref.Project();
     ref.setProject(params.project_id);
-    let req = new GetProjectRequest();
+    let req = new UI.GetProjectRequest();
     req.setProject(ref);
 
-    let resp = await this.api.client.getProject(req, this.api.WithMeta());
+    let resp = await this.api.client.uI_GetProject(req, this.api.WithMeta());
     let project = resp.getProject();
 
     if (!project) {
@@ -35,7 +37,13 @@ export default class ProjectDetail extends Route {
       throw new Error(`Project ${params.project_id} not found`);
     }
 
-    return project.toObject();
+    let result = project.toObject() as Model;
+
+    // TODO(jgwhite): It’d be better not to sneak this onto the project,
+    // but changing the model type of this route is way more disruptive.
+    result.latestInitJob = resp.getLatestInitJob()?.toObject();
+
+    return result;
   }
 
   afterModel(): void {
